==> foundation-1.0.0.tgz: package/lib/esm/Link.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css, useTheme } from "@emotion/react";
export default (function (props) {
    var _a = useTheme(), c = _a.c, s = _a.s;
    return (_jsx("a", __assign({ href: props.href, target: props.newTab ? "_blank" : undefined, css: css(css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          border-radius: ", ";\n          &:focus-visible {\n            outline: ", " solid ", ";\n          }\n        "], ["\n          border-radius: ", ";\n          &:focus-visible {\n            outline: ", " solid ", ";\n          }\n        "])), s.sm3, s.sm3, c.outline), props.inline
            ? {
                display: "inline-block",
                textDecoration: "underline",
                color: c.link,
            }
            : {
                display: "block",
                textDecoration: "none",
                color: "inherit",
            }) }, { children: props.children })));
});
var templateObject_1;

==> foundation-1.0.1.tgz: package/lib/esm/Link.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css, useTheme } from "@emotion/react";
export default (function (props) {
    var _a = useTheme(), c = _a.c, s = _a.s;
    return (_jsx("a", __assign({ href: props.href, target: props.newTab ? "_blank" : undefined, css: css(css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          border-radius: ", ";\n          &:focus-visible {\n            outline: ", " solid ", ";\n          }\n        "], ["\n          border-radius: ", ";\n          &:focus-visible {\n            outline: ", " solid ", ";\n          }\n        "])), s.xxs, s.xxs, c.outline), props.inline
            ? {
                display: "inline-block",
                textDecoration: "underline",
                color: c.link,
            }
            : {
                display: "block",
                textDecoration: "none",
                color: "inherit",
            }) }, { children: props.children })));
});
var templateObject_1;
